@@ -1,5 +1,5 @@
 package Text::Hogan;
-$Text::Hogan::VERSION = '1.02';
+$Text::Hogan::VERSION = '1.03';
 use strict;
 use warnings;
 
@@ -13,7 +13,7 @@ Text::Hogan - A mustache templating engine statement-for-statement cloned from h
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 DESCRIPTION
 
@@ -61,8 +61,7 @@ does not support pre-compilation.
 =head2 Template::Mustache
 
 L<Template::Mustache|Template::Mustache> is a module written by Pieter van de
-Bruggen and Ricardo Signes. Currently has no POD. Used by
-Dancer::Template::Mustache.
+Bruggen. Currently has no POD. Used by Dancer::Template::Mustache.
 
 =head2 Mustache::Simple
 
